@@ -60,7 +60,6 @@ import java.util.List;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import javax.mail.internet.AddressException;
-import org.apache.commons.logging.Log;
 import com.gargoylesoftware.htmlunit.WebClient;
 import com.google.gdata.client.GoogleService.InvalidCredentialsException;
 import com.google.gdata.client.Service;
@@ -77,6 +76,8 @@ import com.google.gdata.util.AuthenticationException;
 import com.google.gdata.util.ServiceException;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.container.Contact;
+import com.openexchange.java.Strings;
+import com.openexchange.java.util.TimeZones;
 import com.openexchange.mail.mime.QuotedInternetAddress;
 import com.openexchange.subscribe.SubscriptionErrorMessage;
 import com.openexchange.subscribe.crawler.internal.AbstractStep;
@@ -91,7 +92,7 @@ public class GoogleAPIStep extends AbstractStep<Contact[], Object> implements Lo
 
     private String username, password;
 
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(GoogleAPIStep.class);
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(GoogleAPIStep.class);
 
     public GoogleAPIStep() {
         super();
@@ -105,9 +106,6 @@ public class GoogleAPIStep extends AbstractStep<Contact[], Object> implements Lo
 
     @Override
     public void execute(final WebClient webClient) throws OXException {
-
-        final List<Contact> contacts = new ArrayList<Contact>();
-
         // Request the feed
         URL feedUrl;
         try {
@@ -120,12 +118,20 @@ public class GoogleAPIStep extends AbstractStep<Contact[], Object> implements Lo
             // Go ahead...
             final ContactsService myService = new ContactsService("com.openexchange");
             myService.setUserCredentials(username, password);
-            feedUrl = new URL("http://www.google.com/m8/feeds/contacts/" + username + "/full?max-results=5000");
-            final ContactFeed resultFeed = myService.getFeed(feedUrl, ContactFeed.class);
-            for (int i = 0; i < resultFeed.getEntries().size(); i++) {
+            feedUrl = new URL("https://www.google.com/m8/feeds/contacts/" + username + "/full?max-results=5000");
+            exchangeURLStreamHandler(feedUrl);
+
+            final List<ContactEntry> entries = myService.getFeed(feedUrl, ContactFeed.class).getEntries();
+            final int size = entries.size();
+
+            final List<Contact> contacts = new ArrayList<Contact>(size);
+            boolean overQuotaEncountered = false;
+
+            // Iterate one-by-one
+            for (int i = 0; i < size; i++) {
                 try {
                     final Contact contact = new Contact();
-                    final ContactEntry entry = resultFeed.getEntries().get(i);
+                    final ContactEntry entry = entries.get(i);
                     if (entry.hasName()) {
                         final com.google.gdata.data.extensions.Name name = entry.getName();
                         if (name.hasFullName()) {
@@ -193,22 +199,9 @@ public class GoogleAPIStep extends AbstractStep<Contact[], Object> implements Lo
                     }
 
                     if (entry.getBirthday() != null) {
-                        final String birthday = entry.getBirthday().getValue();
-                        final String regex = "([0-9]{4})\\-([0-9]{2})\\-([0-9]{2})";
-                        if (birthday.matches(regex)) {
-                            final Pattern pattern = Pattern.compile(regex);
-                            final Matcher matcher = pattern.matcher(birthday);
-                            if (matcher.matches() && matcher.groupCount() == 3) {
-                                final int year = Integer.valueOf(matcher.group(1));
-                                final int month = Integer.valueOf(matcher.group(2));
-                                final int day = Integer.valueOf(matcher.group(3));
-                                final Calendar cal = Calendar.getInstance();
-                                cal.clear();
-                                cal.set(year, month, day);
-                                contact.setBirthday(cal.getTime());
-                            }
-                        }
+                        setBirthday(contact, entry.getBirthday().getValue());
                     }
+
                     if (entry.hasStructuredPostalAddresses()) {
                         for (final StructuredPostalAddress pa : entry.getStructuredPostalAddresses()) {
                             if (pa.getRel() != null) {
@@ -274,51 +267,108 @@ public class GoogleAPIStep extends AbstractStep<Contact[], Object> implements Lo
                         }
                     }
 
-                    if (entry.getContactPhotoLink() != null && entry.getContactPhotoLink().getEtag() != null) {
-                        final Link photoLink = entry.getContactPhotoLink();
-                        final Service.GDataRequest request = myService.createLinkQueryRequest(photoLink);
-                        request.execute();
-                        final InputStream in = request.getResponseStream();
-                        final ByteArrayOutputStream out = new ByteArrayOutputStream();
-                        final byte[] buffer = new byte[4096];
-                        for (int read = 0; (read = in.read(buffer)) > 0;) {
-                            out.write(buffer, 0, read);
+                    final Link contactPhotoLink = entry.getContactPhotoLink();
+                    if (contactPhotoLink != null && contactPhotoLink.getEtag() != null) {
+                        Service.GDataRequest request = null;
+                        InputStream in = null;
+                        try {
+                            request = myService.createLinkQueryRequest(contactPhotoLink);
+                            request.execute();
+                            in = request.getResponseStream();
+                            final ByteArrayOutputStream out = new ByteArrayOutputStream();
+                            final byte[] buffer = new byte[4096];
+                            for (int read = 0; (read = in.read(buffer)) > 0;) {
+                                out.write(buffer, 0, read);
+                            }
+                            contact.setImage1(out.toByteArray());
+                            contact.setImageContentType("image/jpeg");
+                        } catch (final ServiceException e) {
+                            final String lcm = Strings.toLowerCase(e.getMessage());
+                            if (lcm.indexOf("temporary problem - please try again later and consider using batch operations.") > 0) {
+                                if (!overQuotaEncountered) {
+                                    LOG.warn("Unable to load more Google contact images due to quota restrictions.", e);
+                                    overQuotaEncountered = true;
+                                }
+                            } else {
+                                LOG.warn("Error while trying to load Google contact's image", e);
+                            }
+                        } finally {
+                            if (null != in) {
+                                try {
+                                    in.close();
+                                } catch (final Exception e) {
+                                    // Ignore
+                                }
+                            }
+                            if (null != request) {
+                                try {
+                                    request.end();
+                                } catch (final Exception e) {
+                                    // Ignore
+                                }
+                            }
                         }
-                        contact.setImage1(out.toByteArray());
-                        contact.setImageContentType("image/jpeg");
                     }
 
                     contacts.add(contact);
                 } catch (final NullPointerException e) {
-                    LOG.error(e);
+                    LOG.error(e.toString());
                 }
             }
+
+            output = new Contact[contacts.size()];
+            for (int i = 0; i < output.length && i < contacts.size(); i++) {
+                output[i] = contacts.get(i);
+            }
+            executedSuccessfully = true;
+
         } catch (final MalformedURLException e) {
-            LOG.error(e);
-            LOG.error("User with id=" + workflow.getSubscription().getUserId() + " and context=" + workflow.getSubscription().getContext() + " failed to subscribe source=" + workflow.getSubscription().getSource().getDisplayName() + " with display_name=" + workflow.getSubscription().getDisplayName());
-            throw SubscriptionErrorMessage.TEMPORARILY_UNAVAILABLE.create();
+            LOG.error(e.toString());
+            LOG.error("User with id={} and context={} failed to subscribe source={} with display_name={}", workflow.getSubscription().getUserId(), workflow.getSubscription().getContext(), workflow.getSubscription().getSource().getDisplayName(), workflow.getSubscription().getDisplayName());
+            throw SubscriptionErrorMessage.COMMUNICATION_PROBLEM.create();
         } catch (final IOException e) {
-            LOG.error(e);
-            LOG.error("User with id=" + workflow.getSubscription().getUserId() + " and context=" + workflow.getSubscription().getContext() + " failed to subscribe source=" + workflow.getSubscription().getSource().getDisplayName() + " with display_name=" + workflow.getSubscription().getDisplayName());
-            throw SubscriptionErrorMessage.TEMPORARILY_UNAVAILABLE.create();
+            LOG.error(e.toString());
+            LOG.error("User with id={} and context={} failed to subscribe source={} with display_name={}", workflow.getSubscription().getUserId(), workflow.getSubscription().getContext(), workflow.getSubscription().getSource().getDisplayName(), workflow.getSubscription().getDisplayName());
+            throw SubscriptionErrorMessage.COMMUNICATION_PROBLEM.create();
         } catch (final InvalidCredentialsException e) {
-            LOG.error("User with id=" + workflow.getSubscription().getUserId() + " and context=" + workflow.getSubscription().getContext() + " failed to subscribe source=" + workflow.getSubscription().getSource().getDisplayName() + " with display_name=" + workflow.getSubscription().getDisplayName());
+            LOG.error("User with id={} and context={} failed to subscribe source={} with display_name={}", workflow.getSubscription().getUserId(), workflow.getSubscription().getContext(), workflow.getSubscription().getSource().getDisplayName(), workflow.getSubscription().getDisplayName());
             throw SubscriptionErrorMessage.INVALID_LOGIN.create();
         } catch (final AuthenticationException e) {
-            LOG.error("User with id=" + workflow.getSubscription().getUserId() + " and context=" + workflow.getSubscription().getContext() + " failed to subscribe source=" + workflow.getSubscription().getSource().getDisplayName() + " with display_name=" + workflow.getSubscription().getDisplayName());
+            LOG.error("User with id={} and context={} failed to subscribe source={} with display_name={}", workflow.getSubscription().getUserId(), workflow.getSubscription().getContext(), workflow.getSubscription().getSource().getDisplayName(), workflow.getSubscription().getDisplayName());
             throw SubscriptionErrorMessage.INVALID_LOGIN.create();
         } catch (final ServiceException e) {
-            LOG.error(e.getMessage(), e);
-            LOG.error("User with id=" + workflow.getSubscription().getUserId() + " and context=" + workflow.getSubscription().getContext() + " failed to subscribe source=" + workflow.getSubscription().getSource().getDisplayName() + " with display_name=" + workflow.getSubscription().getDisplayName());
-            throw SubscriptionErrorMessage.TEMPORARILY_UNAVAILABLE.create();
+            LOG.error("", e);
+            LOG.error("User with id={} and context={} failed to subscribe source={} with display_name={}", workflow.getSubscription().getUserId(), workflow.getSubscription().getContext(), workflow.getSubscription().getSource().getDisplayName(), workflow.getSubscription().getDisplayName());
+            throw SubscriptionErrorMessage.COMMUNICATION_PROBLEM.create();
         }
+    }
 
-        output = new Contact[contacts.size()];
-        for (int i = 0; i < output.length && i < contacts.size(); i++) {
-            output[i] = contacts.get(i);
+    /**
+     * Sets the birthday for the contact based on the google information
+     *
+     * @param contact - the {@link Contact} to set the birthday for
+     * @param birthday - the string the birthday is included in
+     */
+    protected void setBirthday(Contact contact, String birthday) {
+        if (birthday != null) {
+
+            final String regex = "([0-9]{4})\\-([0-9]{2})\\-([0-9]{2})";
+            if (birthday.matches(regex)) {
+                final Pattern pattern = Pattern.compile(regex);
+                final Matcher matcher = pattern.matcher(birthday);
+                if (matcher.matches() && matcher.groupCount() == 3) {
+                    final int year = Integer.parseInt(matcher.group(1));
+                    final int month = Integer.parseInt(matcher.group(2));
+                    final int day = Integer.parseInt(matcher.group(3));
+                    final Calendar cal = Calendar.getInstance(TimeZones.UTC);
+                    cal.clear();
+                    cal.set(Calendar.DAY_OF_MONTH, day);
+                    cal.set(Calendar.MONTH, month - 1);
+                    cal.set(Calendar.YEAR, year);
+                    contact.setBirthday(cal.getTime());
+                }
+            }
         }
-        executedSuccessfully = true;
-
     }
 
     public String getUsername() {
