@@ -58,7 +58,6 @@ import java.util.Date;
 import java.util.List;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
-import org.apache.commons.logging.Log;
 import com.gargoylesoftware.htmlunit.WebClient;
 import com.google.gdata.client.calendar.CalendarService;
 import com.google.gdata.data.calendar.CalendarEventEntry;
@@ -69,7 +68,6 @@ import com.google.gdata.util.ServiceException;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.calendar.CalendarDataObject;
 import com.openexchange.groupware.container.CalendarObject;
-import com.openexchange.log.LogFactory;
 import com.openexchange.subscribe.SubscriptionErrorMessage;
 import com.openexchange.subscribe.crawler.internal.AbstractStep;
 import com.openexchange.subscribe.crawler.internal.LoginStep;
@@ -81,7 +79,7 @@ import com.openexchange.subscribe.crawler.internal.LoginStep;
  */
 public class GoogleCalendarAPIStep extends AbstractStep<CalendarDataObject[], Object> implements LoginStep {
 
-    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(GoogleCalendarAPIStep.class));
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(GoogleCalendarAPIStep.class);
 
     private String username, password;
 
@@ -91,7 +89,9 @@ public class GoogleCalendarAPIStep extends AbstractStep<CalendarDataObject[], Ob
         final CalendarService myService = new CalendarService("com.openexchange");
         try {
             myService.setUserCredentials(username, password);
-            final URL feedUrl = new URL("http://www.google.com/calendar/feeds/" + username + "/private/full");
+            final URL feedUrl = new URL("https://www.google.com/calendar/feeds/" + username + "/private/full");
+            exchangeURLStreamHandler(feedUrl);
+
             final CalendarEventFeed myFeed = myService.getFeed(feedUrl, CalendarEventFeed.class);
             final List<CalendarDataObject> events = new ArrayList<CalendarDataObject>();
 
@@ -121,13 +121,13 @@ public class GoogleCalendarAPIStep extends AbstractStep<CalendarDataObject[], Ob
             executedSuccessfully = true;
 
         } catch (final IOException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         } catch (final AuthenticationException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         } catch (final ServiceException e) {
-            LOG.error(e);
-            LOG.error("User with id=" + workflow.getSubscription().getUserId() + " and context=" + workflow.getSubscription().getContext() + " failed to subscribe source=" + workflow.getSubscription().getSource().getDisplayName() + " with display_name=" + workflow.getSubscription().getDisplayName());
-            throw SubscriptionErrorMessage.TEMPORARILY_UNAVAILABLE.create();
+            LOG.error(e.toString());
+            LOG.error("User with id={} and context={} failed to subscribe source={} with display_name={}", workflow.getSubscription().getUserId(), workflow.getSubscription().getContext(), workflow.getSubscription().getSource().getDisplayName(), workflow.getSubscription().getDisplayName());
+            throw SubscriptionErrorMessage.COMMUNICATION_PROBLEM.create();
         }
 
     }
@@ -159,9 +159,9 @@ public class GoogleCalendarAPIStep extends AbstractStep<CalendarDataObject[], Ob
                     oxEvent.setEndDate(endDate);
                 }
                 final String recurrenceLine = recurrenceMatcher.group(1);
-                LOG.debug("Event title : " + oxEvent.getTitle());
-                LOG.debug("Start Date : " + oxEvent.getStartDate());
-                LOG.debug("End   Date : " + oxEvent.getEndDate());
+                LOG.debug("Event title : {}", oxEvent.getTitle());
+                LOG.debug("Start Date : {}", oxEvent.getStartDate());
+                LOG.debug("End   Date : {}", oxEvent.getEndDate());
                 LOG.debug(recurrenceLine);
                 // Frequency information will be set here
                 final Pattern frequencyPattern = Pattern.compile("FREQ=([^;]*);");
@@ -170,22 +170,22 @@ public class GoogleCalendarAPIStep extends AbstractStep<CalendarDataObject[], Ob
                     final String freq = frequencyMatcher.group(1);
                     if (freq.equals("DAILY")) {
                         oxEvent.setRecurrenceType(CalendarObject.DAILY);
-                        LOG.debug("Frequence : " + freq);
+                        LOG.debug("Frequence : {}", freq);
                     } else if (freq.equals("WEEKLY")) {
                         oxEvent.setRecurrenceType(CalendarObject.WEEKLY);
-                        LOG.debug("Frequence : " + freq);
+                        LOG.debug("Frequence : {}", freq);
                     } else if (freq.equals("MONTHLY") && startDate != null) {
                         oxEvent.setRecurrenceType(CalendarObject.MONTHLY);
-                        LOG.debug("Frequence : " + freq);
+                        LOG.debug("Frequence : {}", freq);
                         // oxEvent.setDayInMonth(startDate.getDate());
-                        // LOG.debug("***** Day : " + startDate.getDay());
+                        // LOG.debug("***** Day : {}", startDate.getDay());
                     } else if (freq.equals("YEARLY") && startDate != null) {
-                        LOG.debug("Frequence : " + freq);
+                        LOG.debug("Frequence : {}", freq);
                         oxEvent.setRecurrenceType(CalendarObject.YEARLY);
                         oxEvent.setDayInMonth(startDate.getDate());
                         oxEvent.setMonth(startDate.getMonth());
-                        LOG.debug("Month : " + startDate.getMonth());
-                        LOG.debug("Day in Month : " + startDate.getDate());
+                        LOG.debug("Month : {}", startDate.getMonth());
+                        LOG.debug("Day in Month : {}", startDate.getDate());
                     }
                 }
                 // WeekDay information will be set here
@@ -193,7 +193,7 @@ public class GoogleCalendarAPIStep extends AbstractStep<CalendarDataObject[], Ob
                 final Matcher weekDayMatcher = weekDayPattern.matcher(recurrenceLine);
                 if (weekDayMatcher.find()) {
                     final String weekDay = weekDayMatcher.group(1);
-                    LOG.debug("Weekday : " + weekDay);
+                    LOG.debug("Weekday : {}", weekDay);
                     if (weekDay.equals("MO")) {
                         oxEvent.setDays(CalendarObject.MONDAY);
                     } else if (weekDay.equals("TU")) {
@@ -215,14 +215,14 @@ public class GoogleCalendarAPIStep extends AbstractStep<CalendarDataObject[], Ob
                 final Matcher monthDayMatcher = monthDayPattern.matcher(recurrenceLine);
                 if (monthDayMatcher.find()) {
                     oxEvent.setDayInMonth(Integer.parseInt(monthDayMatcher.group(1)));
-                    LOG.debug("MonthDay : " + Integer.parseInt(monthDayMatcher.group(1)));
+                    LOG.debug("MonthDay : {}", Integer.parseInt(monthDayMatcher.group(1)));
                 }
                 // interval information will be set here (e.g. "every X days/weeks/months/years")
                 final Pattern intervalPattern = Pattern.compile("INTERVAL=([0-9]{1})");
                 final Matcher intervalMatcher = intervalPattern.matcher(recurrenceLine);
                 if (intervalMatcher.find()) {
                     oxEvent.setInterval(Integer.parseInt(intervalMatcher.group(1)));
-                    LOG.debug("Interval : " + Integer.parseInt(intervalMatcher.group(1)));
+                    LOG.debug("Interval : {}", Integer.parseInt(intervalMatcher.group(1)));
                 } else {
                     // if there is no interval given we need to set it to 1
                     oxEvent.setInterval(1);
@@ -238,7 +238,7 @@ public class GoogleCalendarAPIStep extends AbstractStep<CalendarDataObject[], Ob
                     final SimpleDateFormat untilDateFormat = new SimpleDateFormat("yyyyMMdd");
                     final Date untilDate = untilDateFormat.parse(untilYear + untilMonth + untilDay);
                     oxEvent.setUntil(untilDate);
-                    LOG.debug("Until-Date : " + untilDate);
+                    LOG.debug("Until-Date : {}", untilDate);
                 }
             }
         } catch (final ParseException e) {
