@@ -51,8 +51,6 @@ package com.openexchange.subscribe.crawler;
 
 import java.io.IOException;
 import java.net.MalformedURLException;
-import org.apache.commons.logging.Log;
-import com.openexchange.log.LogFactory;
 import com.gargoylesoftware.htmlunit.FailingHttpStatusCodeException;
 import com.gargoylesoftware.htmlunit.Page;
 import com.gargoylesoftware.htmlunit.WebClient;
@@ -75,7 +73,7 @@ import com.openexchange.subscribe.crawler.internal.LoginStep;
  */
 public class LoginPageByFormActionStep extends AbstractStep<HtmlPage, Object> implements LoginStep, HasLoginPage {
 
-    private static Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(LoginPageByFormActionStep.class));
+    private static org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(LoginPageByFormActionStep.class);
 
     private String url, username, password, actionOfLoginForm, nameOfUserField, nameOfPasswordField, linkAvailableAfterLogin, baseUrl, nameOfSubmit;
 
@@ -125,7 +123,7 @@ public class LoginPageByFormActionStep extends AbstractStep<HtmlPage, Object> im
             HtmlForm loginForm = null;
             int numberOfFormCounter = 1;
             for (final HtmlForm form : loginPage.getForms()) {
-                LOG.debug("Forms action attribute / number is : " + form.getActionAttribute() + " / " + numberOfFormCounter + ", should be " + actionOfLoginForm + " / "+numberOfForm);
+                LOG.debug("Forms action attribute / number is : {} / {}, should be {} / {}", form.getActionAttribute(), numberOfFormCounter, actionOfLoginForm, numberOfForm);
                 if (form.getActionAttribute().startsWith(actionOfLoginForm) && numberOfForm == numberOfFormCounter && form.getInputsByName(nameOfUserField) != null) {
                     loginForm = form;
                 }
@@ -154,8 +152,8 @@ public class LoginPageByFormActionStep extends AbstractStep<HtmlPage, Object> im
                     }
                 }
                 if (!linkAvailable) {
-                    LOG.error("Login for url "+ url +" failed!");
-                    LOG.debug("Page that does not have the link to imply a successful login : " + output.getWebResponse().getContentAsString());
+                    LOG.error("Login for url {} failed!", url);
+                    LOG.debug("Page that does not have the link to imply a successful login : {}", output.getWebResponse().getContentAsString());
                     throw SubscriptionErrorMessage.INVALID_LOGIN.create();
                 }
                 executedSuccessfully = true;
