@@ -104,7 +104,12 @@ public class SubscriptionSourceJSONWriter implements SubscriptionSourceJSONWrite
                 if(ID.equals(field)) {
                     row.put(source.getId());
                 } else if (DISPLAY_NAME.equals(field)) {
-                    row.put(source.getDisplayName());
+                    String displayName = source.getDisplayName();
+                    if (source.isLocalizableDisplayName() && translator != null) {
+                        displayName = translator.translate(displayName);
+                    }
+
+                    row.put(displayName);
                 } else if (ICON.equals(field)) {
                     row.put(source.getIcon());
                 } else if (FORM_DESCRIPTION.equals(field)) {
