@@ -66,7 +66,7 @@ import com.openexchange.subscribe.osgi.tools.WhiteboardSubscriptionSourceDiscove
  */
 public class ServletActivator extends AbstractSessionServletActivator {
 
-    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(ServletActivator.class));
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(ServletActivator.class);
 
     private static final String SUBSCRIPTION_ALIAS_APPENDIX = "subscriptions";
 
@@ -93,7 +93,7 @@ public class ServletActivator extends AbstractSessionServletActivator {
             registerSessionServlet(dispatcherPrefixService.getPrefix() + SUBSCRIPTION_ALIAS_APPENDIX, new SubscriptionServlet());
             LOG.info("Registered Servlets for Subscriptions");
         } catch (final Exception e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
         }
     }
 
