@@ -52,9 +52,7 @@ package com.openexchange.subscribe.microformats.datasources;
 import java.io.IOException;
 import java.io.Reader;
 import org.apache.commons.httpclient.HttpException;
-import org.apache.commons.logging.Log;
 import com.openexchange.exception.OXException;
-import com.openexchange.log.LogFactory;
 import com.openexchange.subscribe.Subscription;
 import com.openexchange.subscribe.microformats.OXMFSubscriptionErrorMessage;
 
@@ -67,7 +65,7 @@ public class HTTPOXMFDataSource implements OXMFDataSource {
 
     private static final String URL = "url";
 
-    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(HTTPOXMFDataSource.class));
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(HTTPOXMFDataSource.class);
 
     @Override
     public Reader getData(Subscription subscription) throws OXException {
@@ -76,10 +74,10 @@ public class HTTPOXMFDataSource implements OXMFDataSource {
         try {
             return HTTPToolkit.grab(site);
         } catch (HttpException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
             throw OXMFSubscriptionErrorMessage.ERROR_LOADING_SUBSCRIPTION.create(e, site);
         } catch (IOException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
             throw OXMFSubscriptionErrorMessage.ERROR_LOADING_SUBSCRIPTION.create(e, site);
         }
 
